# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_access_token_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_customer_response

class GetAccessTokenResponse(object):

    """Implementation of the 'GetAccessTokenResponse' model.

    Response object for getting a access token

    Attributes:
        id (string): TODO: type description here.
        code (string): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        customer (GetCustomerResponse): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "code":'code',
        "status":'status',
        "created_at":'created_at',
        "customer":'customer'
    }

    def __init__(self,
                 id=None,
                 code=None,
                 status=None,
                 created_at=None,
                 customer=None):
        """Constructor for the GetAccessTokenResponse class"""

        # Initialize members of the class
        self.id = id
        self.code = code
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.customer = customer


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        code = dictionary.get('code')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None

        # Return an object of this model
        return cls(id,
                   code,
                   status,
                   created_at,
                   customer)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_phone_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class GetPhoneResponse(object):

    """Implementation of the 'GetPhoneResponse' model.

    TODO: type model description here.

    Attributes:
        country_code (string): TODO: type description here.
        number (string): TODO: type description here.
        area_code (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "country_code":'country_code',
        "number":'number',
        "area_code":'area_code'
    }

    def __init__(self,
                 country_code=None,
                 number=None,
                 area_code=None):
        """Constructor for the GetPhoneResponse class"""

        # Initialize members of the class
        self.country_code = country_code
        self.number = number
        self.area_code = area_code


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        country_code = dictionary.get('country_code')
        number = dictionary.get('number')
        area_code = dictionary.get('area_code')

        # Return an object of this model
        return cls(country_code,
                   number,
                   area_code)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_transaction_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_split_response
import mundiapi.models.get_card_response
import mundiapi.models.get_billing_address_response

class GetTransactionResponse(object):

    """Implementation of the 'GetTransactionResponse' model.

    Generic response object for getting a transaction.

    Attributes:
        gateway_id (string): Gateway transaction id
        amount (int): Amount in cents
        status (string): Transaction status
        success (bool): Indicates if the transaction ocurred successfuly
        created_at (datetime): Creation date
        updated_at (datetime): Last update date
        attempt_count (int): Number of attempts tried
        max_attempts (int): Max attempts
        splits (list of GetSplitResponse): Splits
        id (string): Código da transação
        next_attempt (datetime): Date and time of the next attempt
        transaction_type (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetTransactionResponse class"""

        # Initialize members of the class
        self.gateway_id = gateway_id
        self.amount = amount
        self.status = status
        self.success = success
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.attempt_count = attempt_count
        self.max_attempts = max_attempts
        self.splits = splits
        self.id = id
        self.next_attempt = APIHelper.RFC3339DateTime(next_attempt) if next_attempt else None
        self.transaction_type = transaction_type


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        discriminators = {
            'credit_card': GetCreditCardTransactionResponse.from_dictionary,
            'voucher': GetVoucherTransactionResponse.from_dictionary,
            'bank_transfer': GetBankTransferTransactionResponse.from_dictionary,
            'safetypay': GetSafetyPayTransactionResponse.from_dictionary,
            'boleto': GetBoletoTransactionResponse.from_dictionary
        }
        unboxer = discriminators.get(dictionary.get('transaction_type'))

        # Delegate unboxing to another function if a discriminator
        # value for a child class is present.
        if unboxer:
            return unboxer(dictionary)

        # Extract variables from the dictionary
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   next_attempt,
                   transaction_type)


class GetCreditCardTransactionResponse(GetTransactionResponse):

    """Implementation of the 'GetCreditCardTransactionResponse' model.

    Response object for getting a credit card transaction
    NOTE: This class inherits from 'GetTransactionResponse'.

    Attributes:
        statement_descriptor (string): Text that will appear on the credit
            card's statement
        acquirer_name (string): Acquirer name
        acquirer_affiliation_code (string): Aquirer affiliation code
        acquirer_tid (string): Acquirer TID
        acquirer_nsu (string): Acquirer NSU
        acquirer_auth_code (string): Acquirer authorization code
        operation_type (string): Operation type
        card (GetCardResponse): Card data
        acquirer_message (string): Acquirer message
        acquirer_return_code (string): Acquirer Return Code
        installments (int): Number of installments

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_descriptor":'statement_descriptor',
        "acquirer_name":'acquirer_name',
        "acquirer_affiliation_code":'acquirer_affiliation_code',
        "acquirer_tid":'acquirer_tid',
        "acquirer_nsu":'acquirer_nsu',
        "acquirer_auth_code":'acquirer_auth_code',
        "operation_type":'operation_type',
        "card":'card',
        "acquirer_message":'acquirer_message',
        "acquirer_return_code":'acquirer_return_code',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "installments":'installments',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 statement_descriptor=None,
                 acquirer_name=None,
                 acquirer_affiliation_code=None,
                 acquirer_tid=None,
                 acquirer_nsu=None,
                 acquirer_auth_code=None,
                 operation_type=None,
                 card=None,
                 acquirer_message=None,
                 acquirer_return_code=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 installments=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetCreditCardTransactionResponse class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.acquirer_name = acquirer_name
        self.acquirer_affiliation_code = acquirer_affiliation_code
        self.acquirer_tid = acquirer_tid
        self.acquirer_nsu = acquirer_nsu
        self.acquirer_auth_code = acquirer_auth_code
        self.operation_type = operation_type
        self.card = card
        self.acquirer_message = acquirer_message
        self.acquirer_return_code = acquirer_return_code
        self.installments = installments

        # Call the constructor for the base class
        super(GetCreditCardTransactionResponse, self).__init__(gateway_id,
                                                               amount,
                                                               status,
                                                               success,
                                                               created_at,
                                                               updated_at,
                                                               attempt_count,
                                                               max_attempts,
                                                               splits,
                                                               id,
                                                               next_attempt,
                                                               transaction_type)


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_descriptor = dictionary.get('statement_descriptor')
        acquirer_name = dictionary.get('acquirer_name')
        acquirer_affiliation_code = dictionary.get('acquirer_affiliation_code')
        acquirer_tid = dictionary.get('acquirer_tid')
        acquirer_nsu = dictionary.get('acquirer_nsu')
        acquirer_auth_code = dictionary.get('acquirer_auth_code')
        operation_type = dictionary.get('operation_type')
        card = mundiapi.models.get_card_response.GetCardResponse.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        acquirer_message = dictionary.get('acquirer_message')
        acquirer_return_code = dictionary.get('acquirer_return_code')
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        installments = dictionary.get('installments')
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(statement_descriptor,
                   acquirer_name,
                   acquirer_affiliation_code,
                   acquirer_tid,
                   acquirer_nsu,
                   acquirer_auth_code,
                   operation_type,
                   card,
                   acquirer_message,
                   acquirer_return_code,
                   gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   installments,
                   next_attempt,
                   transaction_type)


class GetVoucherTransactionResponse(GetTransactionResponse):

    """Implementation of the 'GetVoucherTransactionResponse' model.

    Response for voucher transactions
    NOTE: This class inherits from 'GetTransactionResponse'.

    Attributes:
        statement_descriptor (string): Text that will appear on the voucher's
            statement
        acquirer_name (string): Acquirer name
        acquirer_affiliation_code (string): Acquirer affiliation code
        acquirer_tid (string): Acquirer TID
        acquirer_nsu (string): Acquirer NSU
        acquirer_auth_code (string): Acquirer authorization code
        acquirer_message (string): acquirer_message
        acquirer_return_code (string): Acquirer return code
        operation_type (string): Operation type
        card (GetCardResponse): Card data

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_descriptor":'statement_descriptor',
        "acquirer_name":'acquirer_name',
        "acquirer_affiliation_code":'acquirer_affiliation_code',
        "acquirer_tid":'acquirer_tid',
        "acquirer_nsu":'acquirer_nsu',
        "acquirer_auth_code":'acquirer_auth_code',
        "acquirer_message":'acquirer_message',
        "acquirer_return_code":'acquirer_return_code',
        "operation_type":'operation_type',
        "card":'card',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 statement_descriptor=None,
                 acquirer_name=None,
                 acquirer_affiliation_code=None,
                 acquirer_tid=None,
                 acquirer_nsu=None,
                 acquirer_auth_code=None,
                 acquirer_message=None,
                 acquirer_return_code=None,
                 operation_type=None,
                 card=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetVoucherTransactionResponse class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.acquirer_name = acquirer_name
        self.acquirer_affiliation_code = acquirer_affiliation_code
        self.acquirer_tid = acquirer_tid
        self.acquirer_nsu = acquirer_nsu
        self.acquirer_auth_code = acquirer_auth_code
        self.acquirer_message = acquirer_message
        self.acquirer_return_code = acquirer_return_code
        self.operation_type = operation_type
        self.card = card

        # Call the constructor for the base class
        super(GetVoucherTransactionResponse, self).__init__(gateway_id,
                                                            amount,
                                                            status,
                                                            success,
                                                            created_at,
                                                            updated_at,
                                                            attempt_count,
                                                            max_attempts,
                                                            splits,
                                                            id,
                                                            next_attempt,
                                                            transaction_type)


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_descriptor = dictionary.get('statement_descriptor')
        acquirer_name = dictionary.get('acquirer_name')
        acquirer_affiliation_code = dictionary.get('acquirer_affiliation_code')
        acquirer_tid = dictionary.get('acquirer_tid')
        acquirer_nsu = dictionary.get('acquirer_nsu')
        acquirer_auth_code = dictionary.get('acquirer_auth_code')
        acquirer_message = dictionary.get('acquirer_message')
        acquirer_return_code = dictionary.get('acquirer_return_code')
        operation_type = dictionary.get('operation_type')
        card = mundiapi.models.get_card_response.GetCardResponse.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(statement_descriptor,
                   acquirer_name,
                   acquirer_affiliation_code,
                   acquirer_tid,
                   acquirer_nsu,
                   acquirer_auth_code,
                   acquirer_message,
                   acquirer_return_code,
                   operation_type,
                   card,
                   gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   next_attempt,
                   transaction_type)


class GetBankTransferTransactionResponse(GetTransactionResponse):

    """Implementation of the 'GetBankTransferTransactionResponse' model.

    Response object for getting a bank transfer transaction
    NOTE: This class inherits from 'GetTransactionResponse'.

    Attributes:
        url (string): Payment url
        bank_tid (string): Transaction identifier for the bank
        bank (string): Bank
        paid_at (datetime): Payment date
        paid_amount (int): Paid amount

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url":'url',
        "bank_tid":'bank_tid',
        "bank":'bank',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "paid_at":'paid_at',
        "paid_amount":'paid_amount',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 url=None,
                 bank_tid=None,
                 bank=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 paid_at=None,
                 paid_amount=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetBankTransferTransactionResponse class"""

        # Initialize members of the class
        self.url = url
        self.bank_tid = bank_tid
        self.bank = bank
        self.paid_at = APIHelper.RFC3339DateTime(paid_at) if paid_at else None
        self.paid_amount = paid_amount

        # Call the constructor for the base class
        super(GetBankTransferTransactionResponse, self).__init__(gateway_id,
                                                                 amount,
                                                                 status,
                                                                 success,
                                                                 created_at,
                                                                 updated_at,
                                                                 attempt_count,
                                                                 max_attempts,
                                                                 splits,
                                                                 id,
                                                                 next_attempt,
                                                                 transaction_type)


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        bank_tid = dictionary.get('bank_tid')
        bank = dictionary.get('bank')
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        paid_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("paid_at")).datetime if dictionary.get("paid_at") else None
        paid_amount = dictionary.get('paid_amount')
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(url,
                   bank_tid,
                   bank,
                   gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   paid_at,
                   paid_amount,
                   next_attempt,
                   transaction_type)


class GetSafetyPayTransactionResponse(GetTransactionResponse):

    """Implementation of the 'GetSafetyPayTransactionResponse' model.

    Response object for getting a safety pay transaction
    NOTE: This class inherits from 'GetTransactionResponse'.

    Attributes:
        url (string): Payment url
        bank_tid (string): Transaction identifier on bank
        paid_at (datetime): Payment date
        paid_amount (int): Paid amount

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url":'url',
        "bank_tid":'bank_tid',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "paid_at":'paid_at',
        "paid_amount":'paid_amount',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 url=None,
                 bank_tid=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 paid_at=None,
                 paid_amount=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetSafetyPayTransactionResponse class"""

        # Initialize members of the class
        self.url = url
        self.bank_tid = bank_tid
        self.paid_at = APIHelper.RFC3339DateTime(paid_at) if paid_at else None
        self.paid_amount = paid_amount

        # Call the constructor for the base class
        super(GetSafetyPayTransactionResponse, self).__init__(gateway_id,
                                                              amount,
                                                              status,
                                                              success,
                                                              created_at,
                                                              updated_at,
                                                              attempt_count,
                                                              max_attempts,
                                                              splits,
                                                              id,
                                                              next_attempt,
                                                              transaction_type)


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        bank_tid = dictionary.get('bank_tid')
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        paid_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("paid_at")).datetime if dictionary.get("paid_at") else None
        paid_amount = dictionary.get('paid_amount')
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(url,
                   bank_tid,
                   gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   paid_at,
                   paid_amount,
                   next_attempt,
                   transaction_type)


class GetBoletoTransactionResponse(GetTransactionResponse):

    """Implementation of the 'GetBoletoTransactionResponse' model.

    Response object for getting a boleto transaction
    NOTE: This class inherits from 'GetTransactionResponse'.

    Attributes:
        url (string): TODO: type description here.
        bar_code (string): TODO: type description here.
        nosso_numero (string): TODO: type description here.
        bank (string): TODO: type description here.
        document_number (string): TODO: type description here.
        instructions (string): TODO: type description here.
        billing_address (GetBillingAddressResponse): TODO: type description
            here.
        qr_code (string): TODO: type description here.
        line (string): TODO: type description here.
        pdf_password (string): TODO: type description here.
        pdf (string): TODO: type description here.
        paid_amount (string): TODO: type description here.
        mtype (string): TODO: type description here.
        due_at (datetime): TODO: type description here.
        paid_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url":'url',
        "bar_code":'bar_code',
        "nosso_numero":'nosso_numero',
        "bank":'bank',
        "document_number":'document_number',
        "instructions":'instructions',
        "billing_address":'billing_address',
        "qr_code":'qr_code',
        "line":'line',
        "pdf_password":'pdf_password',
        "pdf":'pdf',
        "paid_amount":'paid_amount',
        "mtype":'type',
        "gateway_id":'gateway_id',
        "amount":'amount',
        "status":'status',
        "success":'success',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "attempt_count":'attempt_count',
        "max_attempts":'max_attempts',
        "splits":'splits',
        "id":'id',
        "due_at":'due_at',
        "paid_at":'paid_at',
        "next_attempt":'next_attempt',
        "transaction_type":'transaction_type'
    }

    def __init__(self,
                 url=None,
                 bar_code=None,
                 nosso_numero=None,
                 bank=None,
                 document_number=None,
                 instructions=None,
                 billing_address=None,
                 qr_code=None,
                 line=None,
                 pdf_password=None,
                 pdf=None,
                 paid_amount=None,
                 mtype=None,
                 gateway_id=None,
                 amount=None,
                 status=None,
                 success=None,
                 created_at=None,
                 updated_at=None,
                 attempt_count=None,
                 max_attempts=None,
                 splits=None,
                 id=None,
                 due_at=None,
                 paid_at=None,
                 next_attempt=None,
                 transaction_type=None):
        """Constructor for the GetBoletoTransactionResponse class"""

        # Initialize members of the class
        self.url = url
        self.bar_code = bar_code
        self.nosso_numero = nosso_numero
        self.bank = bank
        self.document_number = document_number
        self.instructions = instructions
        self.billing_address = billing_address
        self.qr_code = qr_code
        self.line = line
        self.pdf_password = pdf_password
        self.pdf = pdf
        self.paid_amount = paid_amount
        self.mtype = mtype
        self.due_at = APIHelper.RFC3339DateTime(due_at) if due_at else None
        self.paid_at = APIHelper.RFC3339DateTime(paid_at) if paid_at else None

        # Call the constructor for the base class
        super(GetBoletoTransactionResponse, self).__init__(gateway_id,
                                                           amount,
                                                           status,
                                                           success,
                                                           created_at,
                                                           updated_at,
                                                           attempt_count,
                                                           max_attempts,
                                                           splits,
                                                           id,
                                                           next_attempt,
                                                           transaction_type)


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        bar_code = dictionary.get('bar_code')
        nosso_numero = dictionary.get('nosso_numero')
        bank = dictionary.get('bank')
        document_number = dictionary.get('document_number')
        instructions = dictionary.get('instructions')
        billing_address = mundiapi.models.get_billing_address_response.GetBillingAddressResponse.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        qr_code = dictionary.get('qr_code')
        line = dictionary.get('line')
        pdf_password = dictionary.get('pdf_password')
        pdf = dictionary.get('pdf')
        paid_amount = dictionary.get('paid_amount')
        mtype = dictionary.get('type')
        gateway_id = dictionary.get('gateway_id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        success = dictionary.get('success')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        attempt_count = dictionary.get('attempt_count')
        max_attempts = dictionary.get('max_attempts')
        splits = None
        if dictionary.get('splits') != None:
            splits = list()
            for structure in dictionary.get('splits'):
                splits.append(mundiapi.models.get_split_response.GetSplitResponse.from_dictionary(structure))
        id = dictionary.get('id')
        due_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("due_at")).datetime if dictionary.get("due_at") else None
        paid_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("paid_at")).datetime if dictionary.get("paid_at") else None
        next_attempt = APIHelper.RFC3339DateTime.from_value(dictionary.get("next_attempt")).datetime if dictionary.get("next_attempt") else None
        transaction_type = dictionary.get('transaction_type')

        # Return an object of this model
        return cls(url,
                   bar_code,
                   nosso_numero,
                   bank,
                   document_number,
                   instructions,
                   billing_address,
                   qr_code,
                   line,
                   pdf_password,
                   pdf,
                   paid_amount,
                   mtype,
                   gateway_id,
                   amount,
                   status,
                   success,
                   created_at,
                   updated_at,
                   attempt_count,
                   max_attempts,
                   splits,
                   id,
                   due_at,
                   paid_at,
                   next_attempt,
                   transaction_type)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_payment_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_credit_card_payment_request
import mundiapi.models.create_boleto_payment_request
import mundiapi.models.create_voucher_payment_request
import mundiapi.models.create_split_request
import mundiapi.models.create_customer_request
import mundiapi.models.create_bank_transfer_payment_request
import mundiapi.models.create_checkout_payment_request

class CreatePaymentRequest(object):

    """Implementation of the 'CreatePaymentRequest' model.

    Payment data

    Attributes:
        payment_method (string): Payment method
        credit_card (CreateCreditCardPaymentRequest): Settings for credit card
            payment
        boleto (CreateBoletoPaymentRequest): Settings for boleto payment
        currency (string): Currency. Must be informed using 3 characters
        voucher (CreateVoucherPaymentRequest): Settings for voucher payment
        metadata (dict<object, string>): Metadata
        split (list of CreateSplitRequest): Splits
        customer_id (string): Customer Id
        customer (CreateCustomerRequest): Customer
        bank_transfer (CreateBankTransferPaymentRequest): Settings for bank
            transfer payment
        gateway_affiliation_id (string): Gateway affiliation code
        amount (int): The amount of the payment, in cents
        checkout (CreateCheckoutPaymentRequest): Settings for checkout
            payment

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_method":'payment_method',
        "credit_card":'credit_card',
        "boleto":'boleto',
        "currency":'currency',
        "voucher":'voucher',
        "metadata":'metadata',
        "split":'split',
        "customer_id":'customer_id',
        "customer":'customer',
        "bank_transfer":'bank_transfer',
        "gateway_affiliation_id":'gateway_affiliation_id',
        "amount":'amount',
        "checkout":'checkout'
    }

    def __init__(self,
                 payment_method=None,
                 credit_card=None,
                 boleto=None,
                 currency=None,
                 voucher=None,
                 metadata=None,
                 split=None,
                 customer_id=None,
                 customer=None,
                 bank_transfer=None,
                 gateway_affiliation_id=None,
                 amount=None,
                 checkout=None):
        """Constructor for the CreatePaymentRequest class"""

        # Initialize members of the class
        self.payment_method = payment_method
        self.credit_card = credit_card
        self.boleto = boleto
        self.currency = currency
        self.voucher = voucher
        self.metadata = metadata
        self.split = split
        self.customer_id = customer_id
        self.customer = customer
        self.bank_transfer = bank_transfer
        self.gateway_affiliation_id = gateway_affiliation_id
        self.amount = amount
        self.checkout = checkout


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_method = dictionary.get('payment_method')
        credit_card = mundiapi.models.create_credit_card_payment_request.CreateCreditCardPaymentRequest.from_dictionary(dictionary.get('credit_card')) if dictionary.get('credit_card') else None
        boleto = mundiapi.models.create_boleto_payment_request.CreateBoletoPaymentRequest.from_dictionary(dictionary.get('boleto')) if dictionary.get('boleto') else None
        currency = dictionary.get('currency')
        voucher = mundiapi.models.create_voucher_payment_request.CreateVoucherPaymentRequest.from_dictionary(dictionary.get('voucher')) if dictionary.get('voucher') else None
        metadata = dictionary.get('metadata')
        split = None
        if dictionary.get('split') != None:
            split = list()
            for structure in dictionary.get('split'):
                split.append(mundiapi.models.create_split_request.CreateSplitRequest.from_dictionary(structure))
        customer_id = dictionary.get('customer_id')
        customer = mundiapi.models.create_customer_request.CreateCustomerRequest.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        bank_transfer = mundiapi.models.create_bank_transfer_payment_request.CreateBankTransferPaymentRequest.from_dictionary(dictionary.get('bank_transfer')) if dictionary.get('bank_transfer') else None
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')
        amount = dictionary.get('amount')
        checkout = mundiapi.models.create_checkout_payment_request.CreateCheckoutPaymentRequest.from_dictionary(dictionary.get('checkout')) if dictionary.get('checkout') else None

        # Return an object of this model
        return cls(payment_method,
                   credit_card,
                   boleto,
                   currency,
                   voucher,
                   metadata,
                   split,
                   customer_id,
                   customer,
                   bank_transfer,
                   gateway_affiliation_id,
                   amount,
                   checkout)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.list_invoices_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_invoice_response
import mundiapi.models.paging_response

class ListInvoicesResponse(object):

    """Implementation of the 'ListInvoicesResponse' model.

    Response object for listing invoices

    Attributes:
        data (list of GetInvoiceResponse): The Invoice objects
        paging (PagingResponse): Paging object

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data":'data',
        "paging":'paging'
    }

    def __init__(self,
                 data=None,
                 paging=None):
        """Constructor for the ListInvoicesResponse class"""

        # Initialize members of the class
        self.data = data
        self.paging = paging


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        data = None
        if dictionary.get('data') != None:
            data = list()
            for structure in dictionary.get('data'):
                data.append(mundiapi.models.get_invoice_response.GetInvoiceResponse.from_dictionary(structure))
        paging = mundiapi.models.paging_response.PagingResponse.from_dictionary(dictionary.get('paging')) if dictionary.get('paging') else None

        # Return an object of this model
        return cls(data,
                   paging)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_seller_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_address_request

class UpdateSellerRequest(object):

    """Implementation of the 'UpdateSellerRequest' model.

    TODO: type model description here.

    Attributes:
        name (string): Seller name
        code (string): Seller code
        description (string): Seller description
        document (string): Seller document CPF or CNPJ
        status (string): TODO: type description here.
        mtype (string): TODO: type description here.
        address (CreateAddressRequest): TODO: type description here.
        metadata (dict<object, string>): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "code":'code',
        "description":'description',
        "document":'document',
        "status":'status',
        "mtype":'type',
        "address":'address',
        "metadata":'metadata'
    }

    def __init__(self,
                 name=None,
                 code=None,
                 description=None,
                 document=None,
                 status=None,
                 mtype=None,
                 address=None,
                 metadata=None):
        """Constructor for the UpdateSellerRequest class"""

        # Initialize members of the class
        self.name = name
        self.code = code
        self.description = description
        self.document = document
        self.status = status
        self.mtype = mtype
        self.address = address
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        code = dictionary.get('code')
        description = dictionary.get('description')
        document = dictionary.get('document')
        status = dictionary.get('status')
        mtype = dictionary.get('type')
        address = mundiapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(name,
                   code,
                   description,
                   document,
                   status,
                   mtype,
                   address,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_pricing_scheme_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_price_bracket_response

class GetPricingSchemeResponse(object):

    """Implementation of the 'GetPricingSchemeResponse' model.

    Response object for getting a pricing scheme

    Attributes:
        price (int): TODO: type description here.
        scheme_type (string): TODO: type description here.
        price_brackets (list of GetPriceBracketResponse): TODO: type
            description here.
        minimum_price (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "price":'price',
        "scheme_type":'scheme_type',
        "price_brackets":'price_brackets',
        "minimum_price":'minimum_price'
    }

    def __init__(self,
                 price=None,
                 scheme_type=None,
                 price_brackets=None,
                 minimum_price=None):
        """Constructor for the GetPricingSchemeResponse class"""

        # Initialize members of the class
        self.price = price
        self.scheme_type = scheme_type
        self.price_brackets = price_brackets
        self.minimum_price = minimum_price


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        price = dictionary.get('price')
        scheme_type = dictionary.get('scheme_type')
        price_brackets = None
        if dictionary.get('price_brackets') != None:
            price_brackets = list()
            for structure in dictionary.get('price_brackets'):
                price_brackets.append(mundiapi.models.get_price_bracket_response.GetPriceBracketResponse.from_dictionary(structure))
        minimum_price = dictionary.get('minimum_price')

        # Return an object of this model
        return cls(price,
                   scheme_type,
                   price_brackets,
                   minimum_price)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_invoice_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_invoice_item_response
import mundiapi.models.get_customer_response
import mundiapi.models.get_charge_response
import mundiapi.models.get_billing_address_response
import mundiapi.models.get_subscription_response
import mundiapi.models.get_period_response
import mundiapi.models.get_shipping_response

class GetInvoiceResponse(object):

    """Implementation of the 'GetInvoiceResponse' model.

    Response object for getting an invoice

    Attributes:
        id (string): TODO: type description here.
        code (string): TODO: type description here.
        url (string): TODO: type description here.
        amount (int): TODO: type description here.
        status (string): TODO: type description here.
        payment_method (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        items (list of GetInvoiceItemResponse): TODO: type description here.
        customer (GetCustomerResponse): TODO: type description here.
        charge (GetChargeResponse): TODO: type description here.
        installments (int): TODO: type description here.
        billing_address (GetBillingAddressResponse): TODO: type description
            here.
        subscription (GetSubscriptionResponse): TODO: type description here.
        cycle (GetPeriodResponse): TODO: type description here.
        shipping (GetShippingResponse): TODO: type description here.
        metadata (dict<object, string>): TODO: type description here.
        due_at (datetime): TODO: type description here.
        canceled_at (datetime): TODO: type description here.
        billing_at (datetime): TODO: type description here.
        seen_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "code":'code',
        "url":'url',
        "amount":'amount',
        "status":'status',
        "payment_method":'payment_method',
        "created_at":'created_at',
        "items":'items',
        "customer":'customer',
        "charge":'charge',
        "installments":'installments',
        "billing_address":'billing_address',
        "subscription":'subscription',
        "cycle":'cycle',
        "shipping":'shipping',
        "metadata":'metadata',
        "due_at":'due_at',
        "canceled_at":'canceled_at',
        "billing_at":'billing_at',
        "seen_at":'seen_at'
    }

    def __init__(self,
                 id=None,
                 code=None,
                 url=None,
                 amount=None,
                 status=None,
                 payment_method=None,
                 created_at=None,
                 items=None,
                 customer=None,
                 charge=None,
                 installments=None,
                 billing_address=None,
                 subscription=None,
                 cycle=None,
                 shipping=None,
                 metadata=None,
                 due_at=None,
                 canceled_at=None,
                 billing_at=None,
                 seen_at=None):
        """Constructor for the GetInvoiceResponse class"""

        # Initialize members of the class
        self.id = id
        self.code = code
        self.url = url
        self.amount = amount
        self.status = status
        self.payment_method = payment_method
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.items = items
        self.customer = customer
        self.charge = charge
        self.installments = installments
        self.billing_address = billing_address
        self.subscription = subscription
        self.cycle = cycle
        self.shipping = shipping
        self.metadata = metadata
        self.due_at = APIHelper.RFC3339DateTime(due_at) if due_at else None
        self.canceled_at = APIHelper.RFC3339DateTime(canceled_at) if canceled_at else None
        self.billing_at = APIHelper.RFC3339DateTime(billing_at) if billing_at else None
        self.seen_at = APIHelper.RFC3339DateTime(seen_at) if seen_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        code = dictionary.get('code')
        url = dictionary.get('url')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        payment_method = dictionary.get('payment_method')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        items = None
        if dictionary.get('items') != None:
            items = list()
            for structure in dictionary.get('items'):
                items.append(mundiapi.models.get_invoice_item_response.GetInvoiceItemResponse.from_dictionary(structure))
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        charge = mundiapi.models.get_charge_response.GetChargeResponse.from_dictionary(dictionary.get('charge')) if dictionary.get('charge') else None
        installments = dictionary.get('installments')
        billing_address = mundiapi.models.get_billing_address_response.GetBillingAddressResponse.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        subscription = mundiapi.models.get_subscription_response.GetSubscriptionResponse.from_dictionary(dictionary.get('subscription')) if dictionary.get('subscription') else None
        cycle = mundiapi.models.get_period_response.GetPeriodResponse.from_dictionary(dictionary.get('cycle')) if dictionary.get('cycle') else None
        shipping = mundiapi.models.get_shipping_response.GetShippingResponse.from_dictionary(dictionary.get('shipping')) if dictionary.get('shipping') else None
        metadata = dictionary.get('metadata')
        due_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("due_at")).datetime if dictionary.get("due_at") else None
        canceled_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("canceled_at")).datetime if dictionary.get("canceled_at") else None
        billing_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("billing_at")).datetime if dictionary.get("billing_at") else None
        seen_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("seen_at")).datetime if dictionary.get("seen_at") else None

        # Return an object of this model
        return cls(id,
                   code,
                   url,
                   amount,
                   status,
                   payment_method,
                   created_at,
                   items,
                   customer,
                   charge,
                   installments,
                   billing_address,
                   subscription,
                   cycle,
                   shipping,
                   metadata,
                   due_at,
                   canceled_at,
                   billing_at,
                   seen_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_card_token_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class GetCardTokenResponse(object):

    """Implementation of the 'GetCardTokenResponse' model.

    Card token data

    Attributes:
        last_four_digits (string): TODO: type description here.
        holder_name (string): TODO: type description here.
        holder_document (string): TODO: type description here.
        exp_month (string): TODO: type description here.
        exp_year (string): TODO: type description here.
        brand (string): TODO: type description here.
        mtype (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "last_four_digits":'last_four_digits',
        "holder_name":'holder_name',
        "holder_document":'holder_document',
        "exp_month":'exp_month',
        "exp_year":'exp_year',
        "brand":'brand',
        "mtype":'type'
    }

    def __init__(self,
                 last_four_digits=None,
                 holder_name=None,
                 holder_document=None,
                 exp_month=None,
                 exp_year=None,
                 brand=None,
                 mtype=None):
        """Constructor for the GetCardTokenResponse class"""

        # Initialize members of the class
        self.last_four_digits = last_four_digits
        self.holder_name = holder_name
        self.holder_document = holder_document
        self.exp_month = exp_month
        self.exp_year = exp_year
        self.brand = brand
        self.mtype = mtype


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        last_four_digits = dictionary.get('last_four_digits')
        holder_name = dictionary.get('holder_name')
        holder_document = dictionary.get('holder_document')
        exp_month = dictionary.get('exp_month')
        exp_year = dictionary.get('exp_year')
        brand = dictionary.get('brand')
        mtype = dictionary.get('type')

        # Return an object of this model
        return cls(last_four_digits,
                   holder_name,
                   holder_document,
                   exp_month,
                   exp_year,
                   brand,
                   mtype)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_plan_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_plan_item_request
import mundiapi.models.create_pricing_scheme_request

class CreatePlanRequest(object):

    """Implementation of the 'CreatePlanRequest' model.

    Request for creating a plan

    Attributes:
        name (string): Plan's name
        description (string): Description
        statement_descriptor (string): Text that will be printed on the credit
            card's statement
        items (list of CreatePlanItemRequest): Plan items
        shippable (bool): Indicates if the plan is shippable
        payment_methods (list of string): Allowed payment methods for the
            plan
        installments (list of int): Number of installments
        currency (string): Currency
        interval (string): Interval
        interval_count (int): Interval counts between two charges. For
            instance, if the interval is 'month' and count is 2, the customer
            will be charged once every two months.
        billing_days (list of int): Allowed billings days for the
            subscription, in case the plan type is 'exact_day'
        billing_type (string): Billing type
        pricing_scheme (CreatePricingSchemeRequest): Plan's pricing scheme
        metadata (dict<object, string>): Metadata
        minimum_price (int): Minimum price that will be charged
        cycles (int): Number of cycles
        quantity (int): Quantity
        trial_period_days (int): Trial period, where the customer will not be
            charged.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "description":'description',
        "statement_descriptor":'statement_descriptor',
        "items":'items',
        "shippable":'shippable',
        "payment_methods":'payment_methods',
        "installments":'installments',
        "currency":'currency',
        "interval":'interval',
        "interval_count":'interval_count',
        "billing_days":'billing_days',
        "billing_type":'billing_type',
        "pricing_scheme":'pricing_scheme',
        "metadata":'metadata',
        "minimum_price":'minimum_price',
        "cycles":'cycles',
        "quantity":'quantity',
        "trial_period_days":'trial_period_days'
    }

    def __init__(self,
                 name=None,
                 description=None,
                 statement_descriptor=None,
                 items=None,
                 shippable=None,
                 payment_methods=None,
                 installments=None,
                 currency=None,
                 interval=None,
                 interval_count=None,
                 billing_days=None,
                 billing_type=None,
                 pricing_scheme=None,
                 metadata=None,
                 minimum_price=None,
                 cycles=None,
                 quantity=None,
                 trial_period_days=None):
        """Constructor for the CreatePlanRequest class"""

        # Initialize members of the class
        self.name = name
        self.description = description
        self.statement_descriptor = statement_descriptor
        self.items = items
        self.shippable = shippable
        self.payment_methods = payment_methods
        self.installments = installments
        self.currency = currency
        self.interval = interval
        self.interval_count = interval_count
        self.billing_days = billing_days
        self.billing_type = billing_type
        self.pricing_scheme = pricing_scheme
        self.metadata = metadata
        self.minimum_price = minimum_price
        self.cycles = cycles
        self.quantity = quantity
        self.trial_period_days = trial_period_days


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        description = dictionary.get('description')
        statement_descriptor = dictionary.get('statement_descriptor')
        items = None
        if dictionary.get('items') != None:
            items = list()
            for structure in dictionary.get('items'):
                items.append(mundiapi.models.create_plan_item_request.CreatePlanItemRequest.from_dictionary(structure))
        shippable = dictionary.get('shippable')
        payment_methods = dictionary.get('payment_methods')
        installments = dictionary.get('installments')
        currency = dictionary.get('currency')
        interval = dictionary.get('interval')
        interval_count = dictionary.get('interval_count')
        billing_days = dictionary.get('billing_days')
        billing_type = dictionary.get('billing_type')
        pricing_scheme = mundiapi.models.create_pricing_scheme_request.CreatePricingSchemeRequest.from_dictionary(dictionary.get('pricing_scheme')) if dictionary.get('pricing_scheme') else None
        metadata = dictionary.get('metadata')
        minimum_price = dictionary.get('minimum_price')
        cycles = dictionary.get('cycles')
        quantity = dictionary.get('quantity')
        trial_period_days = dictionary.get('trial_period_days')

        # Return an object of this model
        return cls(name,
                   description,
                   statement_descriptor,
                   items,
                   shippable,
                   payment_methods,
                   installments,
                   currency,
                   interval,
                   interval_count,
                   billing_days,
                   billing_type,
                   pricing_scheme,
                   metadata,
                   minimum_price,
                   cycles,
                   quantity,
                   trial_period_days)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_token_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_card_token_request

class CreateTokenRequest(object):

    """Implementation of the 'CreateTokenRequest' model.

    Token data

    Attributes:
        mtype (string): Token type
        card (CreateCardTokenRequest): Card data

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "card":'card'
    }

    def __init__(self,
                 mtype='card',
                 card=None):
        """Constructor for the CreateTokenRequest class"""

        # Initialize members of the class
        self.mtype = mtype
        self.card = card


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get("type") if dictionary.get("type") else 'card'
        card = mundiapi.models.create_card_token_request.CreateCardTokenRequest.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None

        # Return an object of this model
        return cls(mtype,
                   card)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_split_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateSplitRequest(object):

    """Implementation of the 'CreateSplitRequest' model.

    Split

    Attributes:
        mtype (string): Split type
        amount (int): Amount
        recipient_id (string): Recipient id

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "amount":'amount',
        "recipient_id":'recipient_id'
    }

    def __init__(self,
                 mtype=None,
                 amount=None,
                 recipient_id=None):
        """Constructor for the CreateSplitRequest class"""

        # Initialize members of the class
        self.mtype = mtype
        self.amount = amount
        self.recipient_id = recipient_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        amount = dictionary.get('amount')
        recipient_id = dictionary.get('recipient_id')

        # Return an object of this model
        return cls(mtype,
                   amount,
                   recipient_id)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_checkout_payment_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_address_request
import mundiapi.models.create_checkout_card_payment_request
import mundiapi.models.create_checkout_boleto_payment_request

class CreateCheckoutPaymentRequest(object):

    """Implementation of the 'CreateCheckoutPaymentRequest' model.

    Checkout payment request

    Attributes:
        accepted_payment_methods (list of string): Accepted Payment Methods
        success_url (string): Success url
        skip_checkout_success_page (bool): Pular tela de sucesso
            pós-pagamento?
        billing_address_editable (bool): Torna o objeto billing address
            editável
        billing_address (CreateAddressRequest): Endereço de cobrança
        default_payment_method (string): Default payment method
        gateway_affiliation_id (string): Gateway Affiliation Id
        credit_card (CreateCheckoutCardPaymentRequest): Card payment request
        boleto (CreateCheckoutBoletoPaymentRequest): Boleto payment request
        customer_editable (bool): Torna o objeto editável
        expires_in (int): Tempo em minutos para a expiração

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "accepted_payment_methods":'accepted_payment_methods',
        "success_url":'success_url',
        "skip_checkout_success_page":'skip_checkout_success_page',
        "billing_address_editable":'billing_address_editable',
        "billing_address":'billing_address',
        "default_payment_method":'default_payment_method',
        "gateway_affiliation_id":'gateway_affiliation_id',
        "credit_card":'credit_card',
        "boleto":'boleto',
        "customer_editable":'customer_editable',
        "expires_in":'expires_in'
    }

    def __init__(self,
                 accepted_payment_methods=None,
                 success_url=None,
                 skip_checkout_success_page=None,
                 billing_address_editable=None,
                 billing_address=None,
                 default_payment_method=None,
                 gateway_affiliation_id=None,
                 credit_card=None,
                 boleto=None,
                 customer_editable=None,
                 expires_in=None):
        """Constructor for the CreateCheckoutPaymentRequest class"""

        # Initialize members of the class
        self.accepted_payment_methods = accepted_payment_methods
        self.success_url = success_url
        self.skip_checkout_success_page = skip_checkout_success_page
        self.billing_address_editable = billing_address_editable
        self.billing_address = billing_address
        self.default_payment_method = default_payment_method
        self.gateway_affiliation_id = gateway_affiliation_id
        self.credit_card = credit_card
        self.boleto = boleto
        self.customer_editable = customer_editable
        self.expires_in = expires_in


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        accepted_payment_methods = dictionary.get('accepted_payment_methods')
        success_url = dictionary.get('success_url')
        skip_checkout_success_page = dictionary.get('skip_checkout_success_page')
        billing_address_editable = dictionary.get('billing_address_editable')
        billing_address = mundiapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        default_payment_method = dictionary.get('default_payment_method')
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')
        credit_card = mundiapi.models.create_checkout_card_payment_request.CreateCheckoutCardPaymentRequest.from_dictionary(dictionary.get('credit_card')) if dictionary.get('credit_card') else None
        boleto = mundiapi.models.create_checkout_boleto_payment_request.CreateCheckoutBoletoPaymentRequest.from_dictionary(dictionary.get('boleto')) if dictionary.get('boleto') else None
        customer_editable = dictionary.get('customer_editable')
        expires_in = dictionary.get('expires_in')

        # Return an object of this model
        return cls(accepted_payment_methods,
                   success_url,
                   skip_checkout_success_page,
                   billing_address_editable,
                   billing_address,
                   default_payment_method,
                   gateway_affiliation_id,
                   credit_card,
                   boleto,
                   customer_editable,
                   expires_in)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_cancel_subscription_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateCancelSubscriptionRequest(object):

    """Implementation of the 'CreateCancelSubscriptionRequest' model.

    Request for canceling a subscription

    Attributes:
        cancel_pending_invoices (bool): Indicates if the pending invoices must
            also be canceled.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "cancel_pending_invoices":'cancel_pending_invoices'
    }

    def __init__(self,
                 cancel_pending_invoices=True):
        """Constructor for the CreateCancelSubscriptionRequest class"""

        # Initialize members of the class
        self.cancel_pending_invoices = cancel_pending_invoices


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        cancel_pending_invoices = dictionary.get("cancel_pending_invoices") if dictionary.get("cancel_pending_invoices") else True

        # Return an object of this model
        return cls(cancel_pending_invoices)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_checkout_payment_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_customer_response
import mundiapi.models.get_address_response
import mundiapi.models.get_checkout_card_payment_response
import mundiapi.models.get_checkout_boleto_payment_response
import mundiapi.models.get_shipping_response

class GetCheckoutPaymentResponse(object):

    """Implementation of the 'GetCheckoutPaymentResponse' model.

    Resposta das configurações de pagamento do checkout

    Attributes:
        id (string): TODO: type description here.
        default_payment_method (string): Meio de pagamento padrão no checkout
        success_url (string): Url de redirecionamento de sucesso após o
            checkou
        payment_url (string): Url para pagamento usando o checkout
        gateway_affiliation_id (string): Código da afiliação onde o pagamento
            será processado no gateway
        accepted_payment_methods (list of string): Meios de pagamento aceitos
            no checkout
        status (string): Status do checkout
        skip_checkout_success_page (bool): Pular tela de sucesso
            pós-pagamento?
        created_at (datetime): Data de criação
        updated_at (datetime): Data de atualização
        customer_editable (bool): Torna o objeto customer editável
        customer (GetCustomerResponse): Dados do comprador
        billingaddress (GetAddressResponse): Dados do endereço de cobrança
        credit_card (GetCheckoutCardPaymentResponse): Configurações de cartão
            de crédito
        boleto (GetCheckoutBoletoPaymentResponse): Configurações de boleto
        billing_address_editable (bool): Indica se o billing address poderá
            ser editado
        shipping (GetShippingResponse): Configurações  de entrega
        shippable (bool): Indica se possui entrega
        currency (string): Moeda
        amount (int): Valor em centavos
        canceled_at (datetime): Data de cancelamento
        closed_at (datetime): Data de fechamento
        expires_at (datetime): Data de expiração

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "default_payment_method":'default_payment_method',
        "success_url":'success_url',
        "payment_url":'payment_url',
        "gateway_affiliation_id":'gateway_affiliation_id',
        "accepted_payment_methods":'accepted_payment_methods',
        "status":'status',
        "skip_checkout_success_page":'skip_checkout_success_page',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "customer_editable":'customer_editable',
        "customer":'customer',
        "billingaddress":'billingaddress',
        "credit_card":'credit_Card',
        "boleto":'boleto',
        "billing_address_editable":'billing_address_editable',
        "shipping":'shipping',
        "shippable":'shippable',
        "currency":'currency',
        "amount":'amount',
        "canceled_at":'canceled_at',
        "closed_at":'closed_at',
        "expires_at":'expires_at'
    }

    def __init__(self,
                 id=None,
                 default_payment_method=None,
                 success_url=None,
                 payment_url=None,
                 gateway_affiliation_id=None,
                 accepted_payment_methods=None,
                 status=None,
                 skip_checkout_success_page=None,
                 created_at=None,
                 updated_at=None,
                 customer_editable=None,
                 customer=None,
                 billingaddress=None,
                 credit_card=None,
                 boleto=None,
                 billing_address_editable=None,
                 shipping=None,
                 shippable=None,
                 currency=None,
                 amount=None,
                 canceled_at=None,
                 closed_at=None,
                 expires_at=None):
        """Constructor for the GetCheckoutPaymentResponse class"""

        # Initialize members of the class
        self.id = id
        self.default_payment_method = default_payment_method
        self.success_url = success_url
        self.payment_url = payment_url
        self.gateway_affiliation_id = gateway_affiliation_id
        self.accepted_payment_methods = accepted_payment_methods
        self.status = status
        self.skip_checkout_success_page = skip_checkout_success_page
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.customer_editable = customer_editable
        self.customer = customer
        self.billingaddress = billingaddress
        self.credit_card = credit_card
        self.boleto = boleto
        self.billing_address_editable = billing_address_editable
        self.shipping = shipping
        self.shippable = shippable
        self.currency = currency
        self.amount = amount
        self.canceled_at = APIHelper.RFC3339DateTime(canceled_at) if canceled_at else None
        self.closed_at = APIHelper.RFC3339DateTime(closed_at) if closed_at else None
        self.expires_at = APIHelper.RFC3339DateTime(expires_at) if expires_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        default_payment_method = dictionary.get('default_payment_method')
        success_url = dictionary.get('success_url')
        payment_url = dictionary.get('payment_url')
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')
        accepted_payment_methods = dictionary.get('accepted_payment_methods')
        status = dictionary.get('status')
        skip_checkout_success_page = dictionary.get('skip_checkout_success_page')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        customer_editable = dictionary.get('customer_editable')
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        billingaddress = mundiapi.models.get_address_response.GetAddressResponse.from_dictionary(dictionary.get('billingaddress')) if dictionary.get('billingaddress') else None
        credit_card = mundiapi.models.get_checkout_card_payment_response.GetCheckoutCardPaymentResponse.from_dictionary(dictionary.get('credit_Card')) if dictionary.get('credit_Card') else None
        boleto = mundiapi.models.get_checkout_boleto_payment_response.GetCheckoutBoletoPaymentResponse.from_dictionary(dictionary.get('boleto')) if dictionary.get('boleto') else None
        billing_address_editable = dictionary.get('billing_address_editable')
        shipping = mundiapi.models.get_shipping_response.GetShippingResponse.from_dictionary(dictionary.get('shipping')) if dictionary.get('shipping') else None
        shippable = dictionary.get('shippable')
        currency = dictionary.get('currency')
        amount = dictionary.get('amount')
        canceled_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("canceled_at")).datetime if dictionary.get("canceled_at") else None
        closed_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("closed_at")).datetime if dictionary.get("closed_at") else None
        expires_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("expires_at")).datetime if dictionary.get("expires_at") else None

        # Return an object of this model
        return cls(id,
                   default_payment_method,
                   success_url,
                   payment_url,
                   gateway_affiliation_id,
                   accepted_payment_methods,
                   status,
                   skip_checkout_success_page,
                   created_at,
                   updated_at,
                   customer_editable,
                   customer,
                   billingaddress,
                   credit_card,
                   boleto,
                   billing_address_editable,
                   shipping,
                   shippable,
                   currency,
                   amount,
                   canceled_at,
                   closed_at,
                   expires_at)


